@@ -36,6 +36,12 @@ class DescribeImageBaselineCheckSummaryRequest(RpcRequest):
 
 	def set_Criteria(self, Criteria):  # String
 		self.add_query_param('Criteria', Criteria)
+	def get_ScanRanges(self): # RepeatList
+		return self.get_query_params().get('ScanRange')
+
+	def set_ScanRanges(self, ScanRange):  # RepeatList
+		for depth1 in range(len(ScanRange)):
+			self.add_query_param('ScanRange.' + str(depth1 + 1), ScanRange[depth1])
 	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
